@@ -5,7 +5,7 @@ use 5.008004;
 use strict;
 use warnings;
 
-our $VERSION = '0.12_01';
+our $VERSION = '0.12_02';
 
 use DateTime 0.1402;
 use DateTime::Calendar::Julian 0.04;
@@ -417,6 +417,20 @@ sub gregorian_deviation {
     return $date->gregorian_deviation;
 }
 
+sub julian_deviation {
+    my ($class, $date) = @_;
+
+    $date ||= $class;
+
+    $date = DateTime->from_object( object => $date )
+	unless 'DateTime' eq ref $date;
+
+    my $year = $date->{local_c}{year};
+    $year-- if $date->{local_c}{month} <= 2;
+
+    return DateTime::Calendar::Julian::_floor($year/100)-DateTime::Calendar::Julian::_floor($year/400)-2;
+}
+
 sub reform_date { return $_[0]->{reform_date} }
 
 # Almost the same as DateTime::week
@@ -746,7 +760,8 @@ will be considered Julian. This is a bug.
 
 These methods accept an additional "reform_date" argument. Note that the
 epoch is defined for most (all?) systems as a date in the Gregorian
-calendar.
+calendar. B<But> this module will still represent it as a Julian date if
+the epoch gives a date before the reform date.
 
 =item * reform_date
 
@@ -806,7 +821,18 @@ L<DateTime::Duration|DateTime::Duration> object is created.) The actual
 order of operation is that specified by L<DateTime|DateTime>: the
 C<days> component of the duration is applied first, then C<months> (with
 the above modification), then C<minutes>, C<seconds>, and
-C<nanoseconds>.
+C<nanoseconds>. This can give rise to commutation/round-trip failures,
+and these may be more common under this change, but this appears to be
+the price of fixing the bug described in the previous paragraph.
+
+The L<DateTime|DateTime> documentation notes that this can happen in
+that module even in simple cases, such as adding a month to (say)
+January 31. It also notes that if order of operation is an issue, you
+can force it by doing something like
+
+ $dt->add( months => 3 )->add( days => 5 );
+
+to force months to be done first.
 
 =item * strftime
 
@@ -821,6 +847,19 @@ Julian calendar. If the parameter $datetime is given, it will be used to
 calculate the result; in this case this method can be used as a class
 method.
 
+This deviation increments on March 1 (Julian) of any year which is a
+leap year in the Julian calendar but not the Gregorian calendar.
+
+=item * julian_deviation( [$datetime] )
+
+This method returns the difference in days between the Gregorian and the
+Julian calendar. If the parameter $datetime is given, it will be used to
+calculate the result; in this case this method can be used as a class
+method.
+
+This deviation increments on March 1 (Gregorian) of any year which is a
+leap year in the Julian calendar but not the Gregorian calendar.
+
 =item * DefaultReformDate
 
 This static method returns a L<DateTime|DateTime> object representing
